package Sah::SchemaR::sah::clause_set;

our $DATE = '2020-05-08'; # DATE
our $VERSION = '0.9.49.0'; # VERSION

our $rschema = ["hash",[{allowed_keys_re=>"\\A(\\.\\w+(\\.\\w+)*|\\w+(\\.\\w+)*(\\([a-z]{2}(_[A-Z]{2})?\\))?)\\z",keys=>{caption=>["str",{req=>1},{}],default_lang=>["str",{match=>"\\A[a-z]{2}(_[A-Z]{2})?\\z",req=>1},{}],defhash_v=>["int",{default=>1,req=>1},{}],description=>["str",{req=>1},{}],name=>["str",{clset=>[{match=>"\\A\\w+\\z","match.err_level"=>"warn","match.err_msg"=>"should be a word"},{max_len=>32,"max_len.err_level"=>"warn","max_len.err_msg"=>"should be short"}],"clset.op"=>"and",req=>1},{}],summary=>["str",{clset=>[{max_len=>72,"max_len.err_level"=>"warn","max_len.err_msg"=>"should be short"},{match=>qr(\n),"match.err_level"=>"warn","match.err_msg"=>"should only be a single-line text","match.op"=>"not"}],"clset.op"=>"and",req=>1},{}],tags=>["array",{of=>["any",{of=>[["str",{req=>1},{}],["defhash",{req=>1},{}]],req=>1},{}]},{}],v=>["float",{default=>1,req=>1},{}],x=>["any",{},{}]},"keys.restrict"=>0,summary=>"DefHash"},{_prop=>{clause=>{},clset=>{},default_lang=>{},defhash_v=>{},description=>{},examples=>{},invalid_examples=>{},name=>{},summary=>{},tags=>{},v=>{},x=>{}}}],["defhash","hash"]];

1;
# ABSTRACT: 

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::SchemaR::sah::clause_set -  

=head1 VERSION

This document describes version 0.9.49.0 of Sah::SchemaR::sah::clause_set (from Perl distribution Sah-Schemas-Sah), released on 2020-05-08.

=head1 DESCRIPTION

This module is automatically generated by Dist::Zilla::Plugin::Sah::Schemas during distribution build.

A Sah::SchemaR::* module is useful if a client wants to quickly lookup the base type of a schema without having to do any extra resolving. With Sah::Schema::*, one might need to do several lookups if a schema is based on another schema, and so on. Compare for example L<Sah::Schema::poseven> vs L<Sah::SchemaR::poseven>, where in Sah::SchemaR::poseven one can immediately get that the base type is C<int>. Currently L<Perinci::Sub::Complete> uses Sah::SchemaR::* instead of Sah::Schema::* for reduced startup overhead when doing tab completion.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Sah>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Sah>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Sah>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
